@@ -7,6 +7,9 @@ import toml
 import sphinx_rtd_theme
 from datetime import datetime
 
+# add flag for readthedocs https://docs.readthedocs.io/en/stable/feature-flags.html#available-flags
+DONT_OVERWRITE_SPHINX_CONTEXT = 'dont_overwrite_sphinx_context'
+
 with open('../../pyproject.toml', 'r') as f:
     conf = toml.load(f)
 # -- Path setup --------------------------------------------------------------
