@@ -5,7 +5,7 @@ from .snake_wrapper import SnakeInstaller
 from .useful_function import __command_required_option_from_option, __replace_package_name, __add_header
 from .global_variable import __dict_context_settings
 
-from .install import __install_local, __install_cluster, __test_install, __required_options
+from .install import __install_local, __install_cluster, __test_install
 from .edit_files import __edit_tools, __edit_cluster_config, __create_config
 from .run import __run_cluster, __run_local
 
@@ -90,7 +90,6 @@ def main_wrapper(soft_path=None, url=None, docs=None, description_tool=None, sin
     # CLUSTER
     @click.command("install_cluster", short_help=f'Install {snake_installer.soft_name} on HPC cluster',
                    context_settings=__dict_context_settings,
-                   cls=__command_required_option_from_option('create_envmodule', __required_options),
                    no_args_is_help=True)
     @click.option('--scheduler', '-s', default="slurm", type=click.Choice(['slurm'], case_sensitive=False),
                   prompt='Choose your HPC scheduler', show_default=True,
