@@ -6,11 +6,6 @@ from .useful_function import multiprocessing_download
 from pathlib import Path
 import subprocess
 
-__required_options = {
-    True: 'modules_dir',
-    False: 'scheduler'
-}
-
 
 def __install_cluster(snake_installer, scheduler, env, bash_completion):
     """Run installation of tool for HPC cluster"""
@@ -59,7 +54,7 @@ def __install_cluster(snake_installer, scheduler, env, bash_completion):
         try:
             # default slurm cookiecutter not contain all snakemake variables
             if scheduler == "slurm":
-                default_slurm = 'cluster-cancel: "scancel"\nrestart-times: 0\njobscript: "slurm-jobscript.sh"\ncluster: ' \
+                default_slurm = 'restart-times: 0\njobscript: "slurm-jobscript.sh"\ncluster: ' \
                                 '"slurm-submit.py"\ncluster-status: "slurm-status.py"\nmax-jobs-per-second: ' \
                                 '1\nmax-status-checks-per-second: 10\nlocal-cores: 1\njobs: 200\nlatency-wait: ' \
                                 '1296000\nprintshellcmds: true\n'
