@@ -56,7 +56,7 @@ class SnakeInstaller:
         self.git_tools_path = self.install_path.joinpath("install_files", "tools_path.yaml") if "git_tools_path" not in self.dico_args else self.dico_args["git_tools_path"]
 
         # cluster settings
-        self.git_cluster_config = self.default_profile.joinpath("install_files", "cluster_config_SLURM.yaml") if "git_cluster_config" not in self.dico_args else self.dico_args["git_cluster_config"]
+        self.git_cluster_config = self.install_path.joinpath("install_files", "cluster_config_SLURM.yaml") if "git_cluster_config" not in self.dico_args else self.dico_args["git_cluster_config"]
 
     @property
     def soft_name(self) -> str:
